@@ -25,6 +25,9 @@
     }
 #endif
 
+#if defined(ARMA_USE_HDF5)
+  #include <hdf5.h>
+#endif
 
 namespace arma
 {
@@ -32,6 +35,24 @@ namespace arma
 #include "armadillo_bits/blas_bones.hpp"
 #include "armadillo_bits/lapack_bones.hpp"
 #include "armadillo_bits/arpack_bones.hpp"
+// no need to include hdf5_bones.hpp -- it only contains #defines for when ARMA_USE_WRAPPER is false.
+
+
+#if defined(ARMA_USE_HDF5)
+  // Wrapper functions: arma::H5open() and arma::H5check_version(), to hijack
+  // calls to H5open() and H5check_version().
+  herr_t H5open()
+    {
+    return ::H5open();
+    }
+  
+  herr_t H5check_version(unsigned majnum, unsigned minnum, unsigned relnum)
+    {
+    return ::H5check_version(majnum, minnum, relnum);
+    }
+#endif
+
+
 
 // at this stage we have prototypes for the real blas, lapack and atlas functions
 
@@ -834,6 +855,144 @@ extern "C"
       }
 
   #endif
-  }
+  
+  
+  
+  #if defined(ARMA_USE_HDF5)
+  
+    hid_t arma_H5Tcopy(hid_t dtype_id)
+      {
+      return H5Tcopy(dtype_id);
+      }
+    
+    hid_t arma_H5Tcreate(H5T_class_t cl, size_t size)
+      {
+      return H5Tcreate(cl, size);
+      }
+    
+    herr_t arma_H5Tinsert(hid_t dtype_id, const char* name, size_t offset, hid_t field_id)
+      {
+      return H5Tinsert(dtype_id, name, offset, field_id);
+      }
+    
+    htri_t arma_H5Tequal(hid_t dtype_id1, hid_t dtype_id2)
+      {
+      return H5Tequal(dtype_id1, dtype_id2);
+      }
+    
+    herr_t arma_H5Tclose(hid_t dtype_id)
+      {
+      return H5Tclose(dtype_id);
+      }
+    
+    hid_t arma_H5Dopen(hid_t loc_id, const char* name, hid_t dapl_id)
+      {
+      return H5Dopen(loc_id, name, dapl_id);
+      }
+    
+    hid_t arma_H5Dget_type(hid_t dataset_id)
+      {
+      return H5Dget_type(dataset_id);
+      }
+    
+    hid_t arma_H5Dcreate(hid_t loc_id, const char* name, hid_t dtype_id, hid_t space_id, hid_t lcpl_id, hid_t dcpl_id, hid_t dapl_id)
+      {
+      return H5Dcreate(loc_id, name, dtype_id, space_id, lcpl_id, dcpl_id, dapl_id);
+      }
+    
+    herr_t arma_H5Dwrite(hid_t dataset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t xfer_plist_id, const void* buf)
+      {
+      return H5Dwrite(dataset_id, mem_type_id, mem_space_id, file_space_id, xfer_plist_id, buf);
+      }
+    
+    herr_t arma_H5Dclose(hid_t dataset_id)
+      {
+      return H5Dclose(dataset_id);
+      }
+    
+    hid_t arma_H5Dget_space(hid_t dataset_id)
+      {
+      return H5Dget_space(dataset_id);
+      }
+    
+    herr_t arma_H5Dread(hid_t dataset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t xfer_plist_id, void* buf)
+      {
+      return H5Dread(dataset_id, mem_type_id, mem_space_id, file_space_id, xfer_plist_id, buf);
+      }
+    
+    int arma_H5Sget_simple_extent_ndims(hid_t space_id)
+      {
+      return H5Sget_simple_extent_ndims(space_id);
+      }
+    
+    int arma_H5Sget_simple_extent_dims(hid_t space_id, hsize_t* dims, hsize_t* maxdims)
+      {
+      return H5Sget_simple_extent_dims(space_id, dims, maxdims);
+      }
+    
+    herr_t arma_H5Sclose(hid_t space_id)
+      {
+      return H5Sclose(space_id);
+      }
+    
+    hid_t arma_H5Screate_simple(int rank, const hsize_t* current_dims, const hsize_t* maximum_dims)
+      {
+      return H5Screate_simple(rank, current_dims, maximum_dims);
+      }
+    
+    herr_t arma_H5Ovisit(hid_t object_id, H5_index_t index_type, H5_iter_order_t order, H5O_iterate_t op, void* op_data)
+      {
+      return H5Ovisit(object_id, index_type, order, op, op_data);
+      }
+    
+    herr_t arma_H5Eset_auto(hid_t estack_id, H5E_auto_t func, void* client_data)
+      {
+      return H5Eset_auto(estack_id, func, client_data);
+      }
+    
+    herr_t arma_H5Eget_auto(hid_t estack_id, H5E_auto_t* func, void** client_data)
+      {
+      return H5Eget_auto(estack_id, func, client_data);
+      }
+    
+    hid_t arma_H5Fopen(const char* name, unsigned flags, hid_t fapl_id)
+      {
+      return H5Fopen(name, flags, fapl_id);
+      }
+    
+    hid_t arma_H5Fcreate(const char* name, unsigned flags, hid_t fcpl_id, hid_t fapl_id)
+      {
+      return H5Fcreate(name, flags, fcpl_id, fapl_id);
+      }
+    
+    herr_t arma_H5Fclose(hid_t file_id)
+      {
+      return H5Fclose(file_id);
+      }
+    
+    htri_t arma_H5Fis_hdf5(const char* name)
+      {
+      return H5Fis_hdf5(name);
+      }
+    
+    // H5T_NATIVE_* types.  The rhs here expands to some macros.
+    hid_t arma_H5T_NATIVE_UCHAR  = H5T_NATIVE_UCHAR;
+    hid_t arma_H5T_NATIVE_CHAR   = H5T_NATIVE_CHAR;
+    hid_t arma_H5T_NATIVE_SHORT  = H5T_NATIVE_SHORT;
+    hid_t arma_H5T_NATIVE_USHORT = H5T_NATIVE_USHORT;
+    hid_t arma_H5T_NATIVE_INT    = H5T_NATIVE_INT;
+    hid_t arma_H5T_NATIVE_UINT   = H5T_NATIVE_UINT;
+    hid_t arma_H5T_NATIVE_LONG   = H5T_NATIVE_LONG;
+    hid_t arma_H5T_NATIVE_ULONG  = H5T_NATIVE_ULONG;
+    hid_t arma_H5T_NATIVE_LLONG  = H5T_NATIVE_LLONG;
+    hid_t arma_H5T_NATIVE_ULLONG = H5T_NATIVE_ULLONG;
+    hid_t arma_H5T_NATIVE_FLOAT  = H5T_NATIVE_FLOAT;
+    hid_t arma_H5T_NATIVE_DOUBLE = H5T_NATIVE_DOUBLE;
 
-}
+  #endif
+  
+  
+  }  // end of extern "C"
+
+
+}  // end of namespace arma
